==> aws_prototyping_sdk.awsui_react_ts_website-0.3.0.tar.gz: package/samples/src/Home.tsx <==
/*********************************************************************************************************************
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

 Licensed under the Apache License, Version 2.0 (the "License").
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 ******************************************************************************************************************** */

import { Container } from "@awsui/components-react";
import { useContext, useEffect } from "react";
import { AppLayoutContext } from "./App";
import { RuntimeConfigContext } from "./Auth";

/**
 * Component to render the home "/" route.
 */
const Home: React.FC = () => {
  const { setAppLayoutProps } = useContext(AppLayoutContext);

  useEffect(() => {
    setAppLayoutProps({
      // customize AppLayoutProps here
    });
  }, [setAppLayoutProps]);

  return (
    <Container header={"Runtime Config"}>
      <RuntimeConfigContext.Consumer>
        { /* Reference runtimeConfig like so */ }
        {({runtimeContext}) => <pre>{JSON.stringify(runtimeContext, null, 2)}</pre>}
      </RuntimeConfigContext.Consumer>
    </Container>
  );
}

export default Home;

==> aws_prototyping_sdk.awsui_react_ts_website-0.3.14.tar.gz: package/samples/src/Home.tsx <==
/*********************************************************************************************************************
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

 Licensed under the Apache License, Version 2.0 (the "License").
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 ******************************************************************************************************************** */

import { Container } from '@awsui/components-react';
import { useContext, useEffect } from 'react';
import { AppLayoutContext } from './App';
import { RuntimeConfigContext } from './Auth';

/**
 * Component to render the home "/" route.
 */
const Home: React.FC = () => {
  const { setAppLayoutProps } = useContext(AppLayoutContext);

  useEffect(() => {
    setAppLayoutProps({
      // customize AppLayoutProps here
    });
  }, [setAppLayoutProps]);

  return (
    <Container header={'Runtime Config'}>
      <RuntimeConfigContext.Consumer>
        { /* Reference runtimeConfig like so */ }
        {({ runtimeContext }) => <pre>{JSON.stringify(runtimeContext, null, 2)}</pre>}
      </RuntimeConfigContext.Consumer>
    </Container>
  );
};

export default Home;
